# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	GNU Readline XS library wrapper
Name:		perl-Term-ReadLine-Gnu
Version:	1.46
Release:	8.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Term-ReadLine-Gnu
Source0:	https://cpan.metacpan.org/modules/by-module/Term/Term-ReadLine-Gnu-%{version}.tar.gz
Patch0:		Term-ReadLine-Gnu-1.45-local.patch
Patch1:		https://patch-diff.githubusercontent.com/raw/hirooih/perl-trg/pull/32.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	ncurses-devel
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	readline-devel
# Module Runtime
BuildRequires:	perl(AutoLoader)
BuildRequires:	perl(Carp)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	expect
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(ExtUtils::testlib)
BuildRequires:	perl(locale)
BuildRequires:	perl(open)
BuildRequires:	perl(Term::ReadLine)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(utf8)
BuildRequires:	perl(vars)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Note that optional Tk test requires a display, so isn't worth bothering with

# Don't "provide" private Perl libs, and filter out docfile dependencies
%global __provides_exclude ^Gnu\\.so
%global __requires_exclude_from %{_docdir}/%{name}-%{version}/eg|%{_docdir}/%{name}/eg

%description
Term::ReadLine::Gnu (TRG) is an implementation of the interface to the GNU
Readline Library. This module gives you input line editing facility, input
history management facility, word completion facility, etc. It uses the real
GNU Readline Library and has the interface with the almost all variables and
functions that are documented in the GNU Readline/History Library. So you can
program your custom editing function, your custom completion function, and so
on with Perl. TRG may be useful for a C programmer to prototype a program that
uses the GNU Readline Library.

%prep
%setup -q -n Term-ReadLine-Gnu-%{version}

# We don't have perl in /usr/local/bin
%patch -P 0

# Fix for C23 compatibility
# https://bugzilla.redhat.com/show_bug.cgi?id=2341037
# https://github.com/hirooih/perl-trg/pull/32
%patch -P 1 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
# Expect is used so that we get a PTY, as if we were
# in a real terminal, where readline works
LANG=C expect -c '
	spawn make test TEST_VERBOSE=1
	expect eof
	exit [lindex [wait] 3]
'

%files
%doc Changes eg/ README.md
%{_bindir}/perlsh
%{perl_vendorarch}/Term/
%{perl_vendorarch}/auto/Term/
%{_mandir}/man1/perlsh.1*
%{_mandir}/man3/Term::ReadLine::Gnu.3*

%changelog
* Thu Jan 23 2025 Paul Howarth <paul@city-fan.org> - 1.46-8
- Fix for C23 compatibility (GH#32, rhbz#2341037)

* Wed Jun 12 2024 Paul Howarth <paul@city-fan.org> - 1.46-7
- Perl 5.40 rebuild

* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 1.46-2
- Perl 5.38 rebuild

* Sat Jul  1 2023 Paul Howarth <paul@city-fan.org> - 1.46-1
- Update to 1.46
  - Reproduce Term::ReadLine::Stub’s behaviour for ornaments (GH#17)
    - The Perl debugger uses these control sequences for online help
    - Fetch the control sequences for outputting bold text as the current
      Term::ReadLine does
  - Let new() fail on multiple instantiation (GH#16)
  - Suppress warning errors on clang
    - Add prototype on every function declaration
    - Use ANSI-C style port definition even for XS code
  - make clean removes '*.dSYM' for macOS
  - INSTALL.md: update content
    - Add install procedure using packages
    - Update and remove old descriptions
- Avoid use of deprecated patch syntax

* Mon Nov 28 2022 Paul Howarth <paul@city-fan.org> - 1.45-1
- Update to 1.45
  - Add support for MSWin32
    - Require the GNU Readline Library 8.1 or later
    - Use xfree in the GNU Readline Library
    - INSTALL.md: Add section "MSWin32 (Strawberry Perl)"
  - Makefile.PL:
    - On macOS Big Sur or later, 'perl Makefile.PL' does not warn any more
      without using ExtUtils::MakeMaker 7.58 or later
  - ppport.h: update from version 3.62 to version 3.68
    - Suppress warning messages, Wcompound-token-split-by-macro, generated by
      clang 12 or later (https://github.com/Perl/perl5/issues/18780)
  - Expand tabs, trim trailing whitespace

* Mon Nov  7 2022 Paul Howarth <paul@city-fan.org> - 1.44-1
- Update to 1.44
  - Change the TERM check as bash does (GH#11); use 'Term::ReadLine::Stub' if
    the environment variable 'TERM' is set to "emacs" or one of the environment
    variables 'INSIDE_EMACS' or 'EMACS' are defined

* Sat Oct  1 2022 Paul Howarth <paul@city-fan.org> - 1.43-1
- Update to 1.43
  - Add support for readline-8.2
    - New functions: rl_trim_arg_from_keyseq, rl_set_timeout, rl_clear_timeout,
      rl_timeout_remaining
    - New variables: rl_eof_found, rl_timeout_event_hook
    - New state values for rl_readline_state: RL_STATE_TIMEOUT, RL_STATE_EOF
  - t/00checkver.t: Check if $TERM is set properly (GH#11)
  - Makefile.PL
    - Warn if $TERM is not set properly (GH#11)
    - Fix for MSYS2: Take care of '\r\n' in the output of rlmalloc
    - guess_malloc_names(): Simplify the control structure
  - INSTALL: Add a section for "MSYS2"
  - Gnu.xs: No more non-ANSI C compiler support (remove PARAM macros)
  - Gnu.pm, Gnu.xs, Gnu/XS.pm: Expand tabs
  - README.md, INSTALL.md: Changed to Markdown
- Use SPDX-format license tag

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 1.42-5
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 1.42-2
- Perl 5.34 rebuild

* Fri May  7 2021 Paul Howarth <paul@city-fan.org> - 1.42-1
- Update to 1.42
  - Makefile.PL: Force rlver to link with a terminal library, to fix compile
    error on some Cygwin environments and others (GH#7)
  - ppport.h: Update from version 3.52 to version 3.62, to fix compile errors
    on PERL_VERSION_LT() in Gnu.c generated by some versions of
    ExtUtils::MakeMaker (GH#8)

* Mon May  3 2021 Paul Howarth <paul@city-fan.org> - 1.41-1
- Update to 1.41
  - Makefile.PL
    - Search a terminal library only when it is necessary (GH#6)
    - Whole refactoring

* Tue Feb 23 2021 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.40
  - Makefile.PL: some more fix for Homebrew on macOS (CPAN RT#133846)
  - Migrate the repository and the bug tracker to GitHub

* Mon Feb 22 2021 Paul Howarth <paul@city-fan.org> - 1.38-1
- Update to 1.38
  - Makefile.PL
    - Run 'brew --prefix ncurses' internally to detect ncurses installed by
      Homebrew on macOS (CPAN RT#133846)
    - Utilize ExtUtils::Liblist::ext() (CPAN RT#134408)
    - Can specify multiple directories for --prefix, --libdir and --includedir
      options by separating them with colons
  - INSTALL
    - Update for changes above and so on
- Always assume we have rpm ≥ 4.9

* Mon Dec 28 2020 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37
  - readline-8.1 support
    - New functions rl_activate_mark, rl_deactivate_mark, rl_keep_mark_active
      and rl_mark_active_p
    - Use native operate_and_get_next on GNU ReadLine 8.1 and later
  - Gnu.xs: warns if attempted completion function returns undef in position 0
    (CPAN RT#132384)
  - ppport.h: Update from version 3.31 to version 3.52
  - Fixes to be more CPAN Testers friendly
  - Makefile.PL exits 0 when $TERM is not set properly (CPAN RT#128806)
  - Update URLs of the GNU Readline Library manual website (CPAN RT#131362)
  - Update URLs of soundgrab

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 1.36-9
- Perl 5.32 rebuild

* Mon Jan  6 2020 Paul Howarth <paul@city-fan.org> - 1.36-6
- Add patch to reflect change of location of the manual website (#1787937)

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1.36-4
- Perl 5.30 rebuild

* Fri Mar  8 2019 Paul Howarth <paul@city-fan.org> - 1.36-3
- Rebuilt for readline 8 in F-30 and Rawhide

* Mon Jan 14 2019 Paul Howarth <paul@city-fan.org> - 1.36-1
- Update to 1.36
  - readline-8.0 support
    - New functions:
      - rl_empty_keymap
      - rl_set_keymap_name
      - rl_check_signals
    - New variables:
      - history_quoting_state
    - rl_function_of_keyseq uses rl_function_of_keyseq_len to support an
      arbitrary key sequence that may include NULs
  - new() checks the number of arguments
  - Make 'use Term::ReadLine::Gnu' fail if $TERM is not set or on a dumb
    terminal; 'use Term::ReadLine' uses Term::ReadLine::Stub instead
    (CPAN RT#123398)
  - Makefile.PL: Checks the tinfo library for Debian
  - Add t/01test_use.t and t/02test_use.t
  - Comment out a hack for the CPAN Test on OpenBSD added in TRG 1.22
  - t/utf8_binary.t, t/utf8_text.t: skipped on Perl 5.8

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.35-8
- Perl 5.28 rebuild

* Thu Mar 22 2018 Paul Howarth <paul@city-fan.org> - 1.35-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop test patches for Perl 5.8.8
  - Drop workaround for F-9 Perl 5.10.0

* Mon Jan 16 2017 Paul Howarth <paul@city-fan.org> - 1.35-2
- Rebuild for readline 7 in Rawhide

* Fri Nov  4 2016 Paul Howarth <paul@city-fan.org> - 1.35-1
- Update to 1.35
  - readline-7.0 support:
    - New functions: rl_clear_visible_line, rl_tty_set_echoing,
      rl_pending_signal
    - New variable: rl_persistent_signal_handlers
  - Gnu.xs: Fix a bug of rl_readline_state variable manifesting on a
    big-endian, sizeof(int)==4, and sizeof(long)==8 platform with the GNU
    Readline Library 7.0 (CPAN RT#118371)
- Re-diff patch for F-9 perl 5.10.0

* Tue Jul 26 2016 Paul Howarth <paul@city-fan.org> - 1.34-2
- Fix FTBFS when perl is not in the minimal buildroot

* Tue Jun 14 2016 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - Improve UTF-8 handling
    - UTF-8 decoding is done at the interface between Perl and XS; this makes
      it possible for UTF-8 strings to be read from the GNU Readline Library
      functions and variables
    - Add enableUTF8() method
    - UTF-8 support is enabled when STDIN is in UTF-8 by the -C command-line
      switch, or PERL_UNICODE environment variable, or IN file handle has utf8
      IO layer, or -enableUTF8 method is called
    - Pop IO layer only when stdio layer is pushed on utf8 layer to support
      Perl 5.8.x
  - rl_save_state(), rl_restore_state(), history_get_history_state() and
    history_set_history_state() are finally implemented
  - Update RL_STATE_* definitions
  - Fix rl_readline_state and history_length variable to be writable
  - Fix rl_completion_quote_character and rl_completion_found_quote variable to
    be read-only
  - Update POD document
  - t/*.t: Improve and use Test::More
  - t/utf8_binary.t, t/utf8_text.t:
    - Use en_US.UTF-8 instead of en_US.utf8 for locale
    - Force the GNU Readline Library 8bit
    - Add variable access test, IO layer check, verbose mode, etc.
    - Use camel characters instead of Japanese kanji characters
  - t/utf8_binary.t: Skip when PERL_UNICODE is set (CPAN RT#114185)
  - t/utf8.txt: Use camel characters instead of Japanese kanji characters
  - t/callback.t: Update comments and code clean-up
  - Use some modern Perl features (but still in 5.8 era)
    - Use file handle references
    - Define export tags
    - Comment out 'use vars' for subroutine name alias
  - Gnu.pm, t/utf8_text.t: Fix version checks for perl 5.10.0
  - t/utf8_text.t: Fix the number of skip for systems that do not support the
    en_US.UTF-8 locale
  - Gnu.pm: Delete old formatted 'use VERSION'
  - ppport.h: Update from version 1.0007 to version 3.31
  - t/utf8_text.t: Fix for the fail when PERL_UNICODE environment variable is
    set
- BR: perl-generators where available
- Update patch for F-9 perl 5.10.0
- Add patch to fix test suite for Red Hat/Fedora Perl 5.8.8

* Sun Mar  6 2016 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - t/utf8_binary.t, t/utf_text.t: skip on non UTF-8 environment
  - t/readline.t: skip the cursor move test for an active CPAN tester's
    environment
- Simplify find commands using -empty and -delete

* Wed Mar  2 2016 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - t/utf8_binary.t: Add a fix to handle escape sequences that rl_initialize
    may output

* Tue Mar  1 2016 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - Pop the stdio PerlIO layer only when utf8 layer is included for remote
    debugging (CPAN RT#110121)
  - Call utf8::decode() for a UTF8-enabled input filehandle (CPAN RT#104239)
  - Call newTTY() any time to set filehandles
  - Make use of 'our' instead of 'use vars'
  - Add tests for UTF-8 handling
  - Pass _rl_store_iostream 'FILE *' instead of 'PerlIO *'
  - Remove T_STDIO definition from typemap
  - Requires 5.8.1

* Wed Sep 23 2015 Paul Howarth <paul@city-fan.org> - 1.28-2
- Port Propagete-PerlIO_return_value_from_STORE.patch to 1.27/8 properly
  (#1264742)

* Tue Sep 22 2015 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Makefile.PL: revert a change on 1.27 which causes fail on the rlmalloc test
    (CPAN RT#107201)
  - t/readline.t, t/history.t: use LC_ALL instead of LANG

* Thu Sep 10 2015 Paul Howarth <paul@city-fan.org> - 1.27-2
- Fix (again) regression with Debug::Client (Bug #1189459, CPAN RT#101078)

* Sun Sep  6 2015 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - readline-7.0 support: new function rl_callback_sigcleanup
  - Improve POD documents
  - Gnu.xs: do not use typedefs that were obsoleted by ReadLine 6.3
  - Fix a wrong fix in 1.21 to let completion_function do case insensitive
    match (CPAN RT#72378)
  - Fix rl_display_match_list to show the first entry of the array; the bug
    caused segmentation fault with readline-7.0
  - Some improvement of Makefile.PL:
    - Add support for homebrew on Mac OS X (CPAN RT#104389)
    - Print an error string when system() fails
    - Specify 'int' on 'main()'
    - Use -O when -D_FORTIFY_SOURCE is defined
- Explicitly BR: perl-devel, needed for EXTERN.h

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 1.26-3
- Perl 5.22 rebuild

* Tue Feb 17 2015 Paul Howarth <paul@city-fan.org> - 1.26-2
- Fix regression with Debug::Client (Bug #1189459, CPAN RT#101078)

* Sun Feb  1 2015 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - Call ornaments() after rl_initialize() to set tty before calling
    rl_initialize() not to output some characters to STDIO (CPAN RT#96569,
    CPAN RT#101196)
  - Make handling of iostreams simple (make _rl_store_iostream() return void
    and remove _rl_fetch_iostream()) (CPAN RT#101078)
  - Fix the Prerequisites section to require Perl 5.8 (it was required since
    TRG 1.23)
  - t/callback.t: add some new Tk-tests from CPAN Testers' site
- Drop workaround for readline < 5.2, no longer needed

* Mon Dec 22 2014 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Fix to call rl_initialize() after I/O stream setting (CPAN RT#96569)
  - t/readline.t: comment-out stty-command calls
  - t/history.t, t/readline.t: print out the corresponding section names in the
    manuals of the libraries
  - eg/perlsh: use 'IO' instead of 'FILEHANDLE', which Perl 5.20 warns
    (CPAN RT#100883)
  - Fix copyright notices to use the year of first publication
- Revert fix for CPAN RT#96569 on old distributions with readline < 5.2 as it
  breaks there
- Update patches as needed
- Classify buildreqs by usage

* Sun Mar 23 2014 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Fix not to make the PerlIO layer empty for Perl 5.8.9 or before
    (CPAN RT#59832)
  - Update Pod document assuming the use of Pod::Simple::HTMLBatch
  - t/00checkver.t: not to use 'display-readline-version') and "use Test;"
  - INSTALL: add "(Install) Using Package" section
- Update patches as needed

* Wed Mar 19 2014 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Add description of the pager command bug in Perl debugger that causes
    segmentation fault (Perl RT#121456)
  - Fix not to clobber binmode layer (utf-8) on filehandles (CPAN RT#59832)
  - Support UTF-8 input as compatible with Term::ReadLine
  - Now Term::ReadLine::Gnu requires perl 5.8.0 or above
  - Define Term::ReadLine::Gnu::ornaments method (CPAN RT#93614)
  - Makefile.PL: fix the URL of the bug-tracker (CPAN RT#93680)
  - eg/perlsh: POD syntax fix (CPAN RT#93895)
  - README: add note for bug-tracker
  - INSTALL: update "1.3 Trouble Shooting"
- Update patches
- Drop %%defattr, redundant since rpm 4.4

* Thu Mar  6 2014 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - Make Kwalitee-friendly:
    - Add MakeMaker options for META.yml
    - Add Changelog
    - Fix POD errors
    - Make .pm versions consistent
    - Use "use warnings"
  - Makefile.PL dies on the CPAN Test for OpenBSD temporarily (hopefully)
- Package perlsh script and its manpage
- Update patches as needed

* Sat Mar  1 2014 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
  - Readline-6.1 support
    - New function rl_free_keymap
    - New variable rl_filename_rewrite_hook
  - Readline-6.3 support
    - New function rl_clear_history
    - New variables rl_signal_event_hook, rl_input_available_hook,
      rl_executing_key, rl_executing_keyseq, rl_key_sequence_length,
      rl_change_environment, rl_filename_stat_hook
  - Make the following variables read-only: rl_executing_macro, history_length,
    rl_readline_state, rl_explicit_arg, rl_numeric_arg, rl_editing_mode
  - Improve backward compatibility variable and function definitions
  - Fix Term::ReadLine::Gnu::XS::_trp_completion_function not to perform a
    case-sensitive filter
  - Fix Gnu.xs:rl_initialize to be compiled with Perl 5.8.5 or before
  - Update Pod documents
  - t/readline.t, t/history.t: add variable access tests
  - t/readline.t: consider .svn directory on filename completion test and to
    set the standard tty setting before re_initialize() being called
  - eg/perlsh makes use of the deferred signal (safe signal) feature
  - Makefile.PL checks whether the xmalloc exported by readline is indeed
    called 'xmalloc' or whether it has been renamed to '_rl_malloc'
  - Makefile.PL: add -DTRL_READLINE_VERSION to show GNU Readline Library
    version in CPAN Tester Reports
  - t/00checkver.t: let messages go to stdout
  - README: add project home page URL and remove out-of-date descriptions
  - INSTALL: add a section "Install on Mac OS X"
- Update patches as needed

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1.20-5
- BR: perl(AutoLoader), perl(Carp), perl(Exporter), perl(ExtUtils::testlib),
  perl(Getopt::Long) and perl(Term::ReadLine)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Drop RPATH removal kludge
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 1.20-4
- Rebuild for perl 5.14.1 in Rawhide
- Tweak provides/requires filters for rpm 4.9 compatibility
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.20-3
- Rebuild for perl 5.12.1 in Rawhide

* Sun May 30 2010 Paul Howarth <paul@city-fan.org> - 1.20-2
- Fix dist tag for RHEL-6 Beta

* Mon May  3 2010 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
  - Copy environment to avoid segfaults on some systems e.g. FreeBSD
  - Skip the test of rl_readline_version for GNU Readline Library 6.1
  - readline-6.1 support: (func rl_free_keymap, var rl_filename_rewrite_hook)
- Revert environment segfault fix with perl < 5.10.1 and use our patch instead

* Fri Mar  5 2010 Paul Howarth <paul@city-fan.org> - 1.19-2
- Make requires/provides filters simpler and more generic
- Kill bogus RPATHs for distros prior to FC-2
- Dist tag for Rawhide no longer needs special-casing

* Mon Mar 23 2009 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19 (ensure the outstream fd inside the readline library is in
  sync - http://bugs.debian.org/236018; various test fixes)
- Drop visible bell test patch, no longer needed

* Fri Mar  6 2009 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18
- * better error checking of Makefile.PL
- * readline-6.0 support
- Filter out unwanted provides for perl shared objects
- Change bogus dependency filtering mechanism to tie in with provides filter
- Update to SLES-compatible dist tag macros
- No longer need to fix up permissions in %%prep

* Wed Jul  2 2008 Paul Howarth <paul@city-fan.org> - 1.17a-2
- Add Lubomir Rintel's workaround from Fedora for perl 5.10.0 build issues
  (#453287, http://rt.perl.org/rt3/Ticket/Display.html?id=56500)
  Should not be needed when Bug #453646 is fixed
- Run test suite in an "expect" wrapper (add buildreq expect, can now
  include t/readline.t again) so we get a pseudo-terminal
- Add Lubomir Rintel's patch to disable visible bell test, which fails on
  perl 5.10.0
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Don't need buildreq bc (where did that come from?)

* Fri Feb  8 2008 Paul Howarth <paul@city-fan.org> - 1.17a-1
- Update to 1.17a
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Don't run t/readline.t test since it's interactive
- Update patch to fix references to /usr/local/bin/perl

* Wed Jun  6 2007 Paul Howarth <paul@city-fan.org> - 1.16-3
- Fix dist tag for Fedora 7 onwards
- Add buildreq perl(ExtUtils::MakeMaker)
- Fix argument order for find with -depth

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 1.16-2
- Fix distribution tags for development releases
- Define %%{__id_u} in a more portable way
- Further simplify bogus dependency filter
- Don't use macros in build-time command paths, hardcode them instead
- Carry on if tests fail (can't read /dev/tty in mock on FC5 onwards)
- Add buildreq ncurses-devel

* Tue Apr  4 2006 Paul Howarth <paul@city-fan.org> - 1.16-1
- Update to 1.16
- Remove buildroot unconditionally in %%clean and %%install
- Own directories properly
- Simplify distribution-detection
- Remove %%__perl_vendorlib macro, not used
- Remove %%__perl_version macro, used only once
- Remove %%__perl_package macro, used only twice
- Use search.cpan.org URLs
- Simplify compiler optimization flag setting
- Simplify filtering of bogus dependencies

* Fri Jun 24 2005 Paul Howarth <paul@city-fan.org> - 1.15-3
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Include README and examples

* Thu Dec  2 2004 Paul Howarth <paul@city-fan.org> - 1.15-2
- Run "make test" with LANG=C to avoid problems with readline 4.3

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15
- Tidy up spec file

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> - 1.14-3
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system. In such cases, just
  rebuild from the source RPM.
- Changed distribution-identifying macros for greater portability.

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> - 1.14-2
- Unified spec file for Red Hat and Fedora Core

* Fri Dec 12 2003 Paul Howarth <paul@city-fan.org> - 1.14-1.fc1
- More macros
- Expanded description
- Add Fedora Core version to RPM release ID

* Wed Nov 26 2003 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14
- Patch modules to remove hardcoded references to /usr/local/bin/perl

* Mon Nov 24 2003 Paul Howarth <paul@city-fan.org>
- Tweak for Fedora

* Sat Oct 26 2002 R P Herrold <herrold@owlriver.com.com>
- Fork and re-config from Chip Turner's <cturner@redhat.com> 
  .spec for perl-Date-Calc.spec
